/* ************************************************************************
 *
 * CookieKeeper - a Mozilla add-on
 * (c) 2013-2015 Yvon TANGUY
 *
 * ***** BEGIN LICENSE BLOCK **********************************************
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * ***** END LICENSE BLOCK **********************************************
 *
 * Main lib component
 *
 * ************************************************************************
 */

"use strict";

const CK_RESOURCE_ALIAS = "cookiekeeper";

let ckMain = {

  init: function() {
    // Aliasing the Public API "cookiekeeper.jsm"
    // https://developer.mozilla.org/en-US/docs/Mozilla/JavaScript_code_modules/Using
    var resource   = Services.io.getProtocolHandler("resource").QueryInterface(Ci.nsIResProtocolHandler);
    var installURI = Services.io.newFileURI(addonData.installPath);

    if (addonData.installPath.isDirectory()) {
      var alias = Services.io.newURI(installURI.spec + "chrome/modules/", null, null);
    } else {
      var alias = Services.io.newURI("jar:" + installURI.spec + "!/chrome/modules/", null, null);
    }
    resource.setSubstitution(CK_RESOURCE_ALIAS, alias);

    Cu.import("resource://cookiekeeper/cookiekeeper.jsm");

    // Init the CookieKeeper public API:
    CookieKeeper.init();

    // Init the locale bundle
    l10n.init(addonData.resourceURI.spec, "cookiekeeper.properties");
    // Set the toolbar icon + tools menu
    ckUi.init();

    // TODO: When bug #564675 is implemented this will no longer be needed
    // Always set the default prefs, because they disappear on restart
    // See: https://bugzilla.mozilla.org/show_bug.cgi?id=564675
    ckPrefs.setDefaultPrefs(addonData);
  },

  uninit: function() {
    ckUi.uninit();

    // Clear unwanted cookies at shutdown
    if (APP_SHUTDOWN == currReason) {
      CookieKeeper.clearAllCookies(true);
    } // APP_SHUTDOWN

    l10n.uninit();

    // Unload the module
    CookieKeeper.uninit();
    Cu.unload("resource://cookiekeeper/cookiekeeper.jsm");
    // Remove the resources alias
    var resource = Services.io.getProtocolHandler("resource").QueryInterface(Ci.nsIResProtocolHandler);
    resource.setSubstitution(CK_RESOURCE_ALIAS, null);
  }
}
